aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoreapache <eapache@f5534014-38df-0310-8fa8-9805f1628bb7>2012-08-22 00:53:13 +0000
committereapache <eapache@f5534014-38df-0310-8fa8-9805f1628bb7>2012-08-22 00:53:13 +0000
commitb7d8ef5430dacf15060f64221ad7a4f2f32d3a71 (patch)
tree4717d9a5b0c836358ad57741e21cae27d1f6703f
parente2a960ca2e6e70d9467e147f053407420aaf79c0 (diff)
From Teguh via https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=7657
Replace the last instance of gnutls_datum with gnutls_datum_t. The former is deprecated, and the latter is already being used elsewhere in the file. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@44611 f5534014-38df-0310-8fa8-9805f1628bb7
-rw-r--r--epan/dissectors/packet-ssl-utils.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-ssl-utils.c b/epan/dissectors/packet-ssl-utils.c
index f1c2a00b05..ca459bbb1c 100644
--- a/epan/dissectors/packet-ssl-utils.c
+++ b/epan/dissectors/packet-ssl-utils.c
@@ -2765,11 +2765,11 @@ Ssl_private_key_t *
ssl_load_key(FILE* fp)
{
/* gnutls makes our work much harder, since we have to work internally with
* s-exp formatted data, but PEM loader exports only in "gnutls_datum"
* format, and a datum -> s-exp convertion function does not exist.
*/
gnutls_x509_privkey_t priv_key;
- gnutls_datum key;
+ gnutls_datum_t key;
gint size;
guint bytes;
@@ -2765,11 +2765,11 @@ Ssl_private_key_t *
{
/* gnutls makes our work much harder, since we have to work internally with
- * s-exp formatted data, but PEM loader exports only in "gnutls_datum"
+ * s-exp formatted data, but PEM loader exports only in "gnutls_datum_t"
* format, and a datum -> s-exp convertion function does not exist.
*/